smartcard.ATR.ATR

# ``smartcard`.`ATR`.`ATR``

class documentation

`class ATR(object):`

View In Hierarchy

ATR class.

Method | `__checksyncbyte__` | Check validity of TS.
Method | `__init__` | Construct a new atr from bytes.
Method | `__initInstance__` | Parse ATR and initialize members:
Method | `__str__` | Returns a string representation of the ATR as a strem of bytes.
Method | `dump` | Dump the details of an ATR.
Method | `getBitRateFactor` | Return bit rate factor.
Method | `getChecksum` | Return the checksum of the ATR. Checksum is mandatory only for T=1.
Method | `getClockRateConversion` | Return clock rate conversion.
Method | `getGuardTime` | Return extra guard time.
Method | `getHistoricalBytes` | Return historical bytes.
Method | `getHistoricalBytesCount` | Return count of historical bytes.
Method | `getInterfaceBytesCount` | Return count of interface bytes.
Method | `getProgrammingCurrent` | Return maximum programming current.
Method | `getProgrammingVoltage` | Return programming voltage.
Method | `getSupportedProtocols` | Returns a dictionnary of supported protocols.
Method | `getTA1` | Return TA1 byte.
Method | `getTB1` | Return TB1 byte.
Method | `getTC1` | Return TC1 byte.
Method | `getTD1` | Return TD1 byte.
Method | `isT0Supported` | Return True if T=0 is supported.
Method | `isT15Supported` | Return True if T=15 is supported.
Method | `isT1Supported` | Return True if T=1 is supported.
Class Variable | `bitratefactor` | Undocumented
Class Variable | `clockrateconversion` | Undocumented
Class Variable | `currenttable` | Undocumented
Instance Variable | `bytes` | Undocumented
Instance Variable | `checksumOK` | Undocumented
Instance Variable | `DI` | Undocumented
Instance Variable | `FI` | Undocumented
Instance Variable | `hasChecksum` | Undocumented
Instance Variable | `hasTA` | Undocumented
Instance Variable | `hasTB` | Undocumented
Instance Variable | `hasTC` | Undocumented
Instance Variable | `hasTD` | Undocumented
Instance Variable | `historicalBytes` | Undocumented
Instance Variable | `II` | Undocumented
Instance Variable | `interfaceBytesCount` | Undocumented
Instance Variable | `K` | Undocumented
Instance Variable | `N` | Undocumented
Instance Variable | `PI1` | Undocumented
Instance Variable | `T0` | Undocumented
Instance Variable | `TA` | Undocumented
Instance Variable | `TB` | Undocumented
Instance Variable | `TC` | Undocumented
Instance Variable | `TCK` | Undocumented
Instance Variable | `TD` | Undocumented
Instance Variable | `TS` | Undocumented
Instance Variable | `Y` | Undocumented

def __checksyncbyte__(self):

Check validity of TS.

def __init__(self, bytes):

Construct a new atr from bytes.

def __initInstance__(self):

Parse ATR and initialize members:

- TS: initial character
- T0: format character
- TA[n], TB[n], TC[n], TD[n], for n=0,1,...: protocol parameters

Note
protocol parameters indices start at 0, e.g. TA[0], TA[1] correspond to the ISO standard TA1, TA2 parameters historicalBytes: the ATR T1, T2, ..., TK historical bytes TCK: checksum byte (only for protocols different from T=0) FI: clock rate conversion factor DI: voltage adjustment factor PI1: programming voltage factor II: maximum programming current factor N: extra guard time

def __str__(self):

Returns a string representation of the ATR as a strem of bytes.

def dump(self):

Dump the details of an ATR.

def getBitRateFactor(self):

Return bit rate factor.

def getChecksum(self):

Return the checksum of the ATR. Checksum is mandatory only for T=1.

def getClockRateConversion(self):

Return clock rate conversion.

def getGuardTime(self):

Return extra guard time.

def getHistoricalBytes(self):

Return historical bytes.

def getHistoricalBytesCount(self):

Return count of historical bytes.

def getInterfaceBytesCount(self):

Return count of interface bytes.

def getProgrammingCurrent(self):

Return maximum programming current.

def getProgrammingVoltage(self):

Return programming voltage.

def getSupportedProtocols(self):

Returns a dictionnary of supported protocols.

def getTA1(self):

Return TA1 byte.

def getTB1(self):

Return TB1 byte.

def getTC1(self):

Return TC1 byte.

def getTD1(self):

Return TD1 byte.

def isT0Supported(self):

Return True if T=0 is supported.

def isT15Supported(self):

Return True if T=15 is supported.

def isT1Supported(self):

Return True if T=1 is supported.

bitratefactor: `list` =

Undocumented

clockrateconversion: `list` =

Undocumented

currenttable: `list` =

Undocumented

bytes =

Undocumented

checksumOK =

Undocumented

DI =

Undocumented

FI =

Undocumented

hasChecksum =

Undocumented

hasTA: `list` =

Undocumented

hasTB: `list` =

Undocumented

hasTC: `list` =

Undocumented

hasTD: `list` =

Undocumented

historicalBytes =

Undocumented

II =

Undocumented

interfaceBytesCount: `int` =

Undocumented

K =

Undocumented

N =

Undocumented

PI1 =

Undocumented

T0 =

Undocumented

TA: `list` =

Undocumented

TB: `list` =

Undocumented

TC: `list` =

Undocumented

TCK =

Undocumented

TD: `list` =

Undocumented

TS =

Undocumented

Y: `list` =

Undocumented